summaryrefslogtreecommitdiffstats
path: root/Source/cmSystemTools.h
diff options
context:
space:
mode:
authorBill Hoffman <bill.hoffman@kitware.com>2003-01-21 17:50:48 (GMT)
committerBill Hoffman <bill.hoffman@kitware.com>2003-01-21 17:50:48 (GMT)
commit2f4ea98a4cf35b0aa6ced86c98c4b96984ef4fb7 (patch)
tree2e7ba2c7d45537691296edc194f605f623bcc3a7 /Source/cmSystemTools.h
parent110bc04bd0125ef746ad8ea239c632831f7c5075 (diff)
downloadCMake-2f4ea98a4cf35b0aa6ced86c98c4b96984ef4fb7.zip
CMake-2f4ea98a4cf35b0aa6ced86c98c4b96984ef4fb7.tar.gz
CMake-2f4ea98a4cf35b0aa6ced86c98c4b96984ef4fb7.tar.bz2
add a fatal error, and make sure c and c++ compilers work before using them
Diffstat (limited to 'Source/cmSystemTools.h')
-rw-r--r--Source/cmSystemTools.h16
1 files changed, 14 insertions, 2 deletions
diff --git a/Source/cmSystemTools.h b/Source/cmSystemTools.h
index 167926a..9c3d2ae 100644
--- a/Source/cmSystemTools.h
+++ b/Source/cmSystemTools.h
@@ -162,12 +162,23 @@ public:
///! Return true if there was an error at any point.
static bool GetErrorOccuredFlag()
{
- return cmSystemTools::s_ErrorOccured;
+ return cmSystemTools::s_ErrorOccured || cmSystemTools::s_FatalErrorOccured;
+ }
+ ///! If this is set to true, cmake stops processing commands.
+ static void SetFatalErrorOccured()
+ {
+ cmSystemTools::s_FatalErrorOccured = true;
+ }
+ ///! Return true if there was an error at any point.
+ static bool GetFatalErrorOccured()
+ {
+ return cmSystemTools::s_FatalErrorOccured;
}
///! Set the error occured flag back to false
static void ResetErrorOccuredFlag()
{
+ cmSystemTools::s_FatalErrorOccured = false;
cmSystemTools::s_ErrorOccured = false;
}
@@ -364,6 +375,7 @@ protected:
private:
static bool s_RunCommandHideConsole;
static bool s_ErrorOccured;
+ static bool s_FatalErrorOccured;
static bool s_DisableMessages;
static bool s_DisableRunCommandOutput;
static ErrorCallback s_ErrorCallback;
@@ -162,12 +162,23 @@ public:
}
- ///! Set the error occured flag back to false
+ ///! Set the error occured flag and fatal error back to false
static void ResetErrorOccuredFlag()
{